Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Cmd = &cobra.Command{ Use: "workflow [operation] [flags]", Short: "Manage service workflows", Long: `This command helps you manage workflows for your services. You can list, describe, get events, resume, retry, and terminate workflows.`, Run: run, SilenceUsage: true, }
Functions ¶
This section is empty.
Types ¶
type DedupedWorkflowEvent ¶ added in v1.0.43
type DedupedWorkflowEvent struct {
EventTime string `json:"eventTime"`
EventType string `json:"eventType"`
Message string `json:"message"`
Occurrences int `json:"occurrences,omitempty"`
FirstSeen string `json:"firstSeen,omitempty"`
LastSeen string `json:"lastSeen,omitempty"`
}
DedupedWorkflowEvent represents a workflow event with deduplication info
type DetailedStepWithDedupedEvents ¶ added in v1.0.43
type DetailedStepWithDedupedEvents struct {
StepName string `json:"stepName"`
Events []DedupedWorkflowEvent `json:"events"`
}
DetailedStepWithDedupedEvents contains a step with deduplicated events
type WorkflowEventFilterOptions ¶ added in v0.14.60
type WorkflowEventFilterOptions struct {
ResourceID string
ResourceKey string
StepNames []string
Detail bool
MaxEvents int
Since string
Until string
}
WorkflowEventFilterOptions contains filtering options for workflow events
type WorkflowEventsSummary ¶ added in v0.14.60
type WorkflowEventsSummary struct {
WorkflowId string `json:"workflowId"`
EnvironmentId string `json:"environmentId"`
ServiceId string `json:"serviceId"`
Resources []WorkflowResourceSummary `json:"resources"`
FilteringStats map[string]interface{} `json:"filteringStats,omitempty"`
AppliedFilters map[string]interface{} `json:"appliedFilters,omitempty"`
}
WorkflowEventsSummary represents the simplified workflow events response
type WorkflowListItem ¶
type WorkflowListItem struct {
ID string `json:"id" table:"ID"`
Status string `json:"status" table:"Status"`
WorkflowType string `json:"workflowType" table:"Workflow Type"`
CloudProvider string `json:"cloudProvider" table:"Cloud Provider"`
StartTime string `json:"startTime" table:"Start Time"`
EndTime string `json:"endTime" table:"End Time"`
OrgName string `json:"orgName" table:"Organization"`
ServicePlanName string `json:"servicePlanName" table:"Service Plan"`
}
type WorkflowResourceSummary ¶ added in v0.14.60
type WorkflowResourceSummary struct {
ResourceId string `json:"resourceId"`
ResourceKey string `json:"resourceKey"`
ResourceName string `json:"resourceName"`
Steps []WorkflowStepSummary `json:"steps"`
}
WorkflowResourceSummary represents a simplified view of resource workflow execution
type WorkflowStepSummary ¶ added in v0.14.60
type WorkflowStepSummary struct {
StepName string `json:"stepName"`
Status string `json:"status"`
StartTime string `json:"startTime,omitempty"`
EndTime string `json:"endTime,omitempty"`
EventCount int `json:"eventCount"`
DetailedStep *DetailedStepWithDedupedEvents `json:"detailedStep,omitempty"`
}
WorkflowStepSummary represents a simplified view of a workflow step with status
Click to show internal directories.
Click to hide internal directories.